# Pandemic

An agent model in which commuting, compliance, testing and contagion parameters drive
infection in a population. Agents follow OU drift processes
on the plane. Viral load is estimated from geohashing. A population 
of 5,000,000 or so can be used without computational issue. 

![](https://github.com/microprediction/pandemic/blob/master/images/pandemic.png)

### Motivaton 

Covered in this [post](https://www.linkedin.com/pulse/pandemic-minimalist-2d-ornstein-uhlenbeck-model-peter-cotton-phd) with 
the followup [here](https://www.linkedin.com/pulse/dear-new-zealand-heres-how-simulate-covid-19-all-your-cotton-phd/) where possible
improvements are also discussed and acknowledgements are made.   

The author is not an epidemiologist. The model expresses no opinions
on the health aspects of COVID-19. The model offers a novel motion model with some interesting
analytic properties also discussed in the [article](https://www.linkedin.com/pulse/dear-new-zealand-heres-how-simulate-covid-19-all-your-cotton-phd/) referenced
above.

### Usage

    pip install pandemic
    >> from pandemic import run
    >> run()
    
See also <a href="https://github.com/microprediction/pandemic/tree/master/examples">examples</a> of
library use and <a href="https://github.com/microprediction/pandemic/tree/master/examples_of_surrogate_use">examples of using the public
database of simulations</a> generated by this model. 

### Crowd-sourced surrogate model 

See <a href="www.swarmprediction.com/about.html">SwarmPrediction.com</a> for an explanation of 
a SETI-like project to crowd-source a surrogate model. 

### Basic elements of the model 

Covered in detail in this [article](https://www.linkedin.com/pulse/dear-new-zealand-heres-how-simulate-covid-19-all-your-cotton-phd/) 

### Contributing 

Opinions and issues are most welcome. 